#
# spec file for package python-patiencediff
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-patiencediff
Version:        0.2.15
Release:        2.1
Summary:        Python implementation of the patiencediff algorithm
License:        GPL-2.0-or-later
Group:          Development/Languages/Python
URL:            https://github.com/breezy-team/patiencediff
Source:         https://files.pythonhosted.org/packages/source/p/patiencediff/patiencediff-%{version}.tar.gz
BuildRequires:  %{python_module devel >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): alts
Requires(preun): alts
%python_subpackages

%description
Python implementation of the patiencediff algorithm.

%prep
%setup -q -n patiencediff-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%python_clone -a %{buildroot}%{_bindir}/patiencediff

%post
%python_install_alternative patiencediff

%postun
%python_uninstall_alternative patiencediff

%check
%pytest

%files %{python_files}
%doc AUTHORS README.rst
%license COPYING
%python_alternative %{_bindir}/patiencediff
%{python_sitearch}/patiencediff
%{python_sitearch}/patiencediff-%{version}*-info

%changelog
* Tue Jun  3 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Tue May  7 2024 Dirk Müller <dmueller@suse.com>
- update to 0.2.15:
  * Update README.rst
  * Add dependabot config
  * Bump actions/setup-python from 2 to 5
  * Bump docker/setup-qemu-action from 1 to 3
  * Bump actions/checkout from 2 to 4
  * Publish wheels from github
  * Drop python 3.7 support
* Tue Dec 12 2023 Dirk Müller <dmueller@suse.com>
- update to 0.2.14:
  * Sort Python import definitions with isort
  * Use disperse action
  * Enable ruff, pyupgrade
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 0.2.12:
  * install patiencediff
  * drop python 3.6
* Tue Dec 13 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.2.11
  * Merge release of 0.2.11
  * Merge pull request #34 from jelmer/release-0.2.11
* Tue Dec  6 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.2.10
  * Merge pull request #33 from jelmer/release-0.2.10
    Merge release of 0.2.10
- Update to version 0.2.9
  * Merge pull request #32 from jelmer/release-0.2.9
    Merge release of 0.2.9
- Update to version 0.2.8
  * Merge pull request #31 from jelmer/bump-version
  * Bump version to 0.2.8
* Wed Nov  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.2.7
  * Make C extension mandatory when running in cibuildwheel.
  * Use more metadata to setup.cfg, use standard optional flag.
  * Fix path.
  * Remove other unused dependencies from pyproject.toml
  * Remove redundant wheel dep from pyproject.toml
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.2.6
  * Fix path.
- Update to version 0.2.4
  * Merge pull request #21 from jelmer/pyproject
  * Add pyproject, depend on cython
* Wed Oct 12 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.2.3
  * No Upstream changelog
* Fri Jul 15 2022 John Vandenberg <jayvdb@gmail.com>
- Add package specific URL
* Sat Mar 26 2022 Dirk Müller <dmueller@suse.com>
- update to 0.2.2:
  * fix license declaration
* Wed Jun 10 2020 pgajdos@suse.com
- initial version 0.2.0, required by breezy
